Skip to contents

Function for diagnosing errors in a run of the pipeline

Usage

diagnose_pipeline(input)

Arguments

input

A character path to an scfg object or an scfg object itself.

Author

Zach Vig & Dan Shallal