Internal helper function to insert a job into the tracking SQLite database
Source:R/job_tracking_functions.R
insert_tracked_job.RdInternal helper function to insert a job into the tracking SQLite database
Usage
insert_tracked_job(sqlite_db, job_id, tracking_args = list())