List postprocessed output files for paired input specifications
Source:R/setup_postprocess.R
get_postproc_output_files.RdConverts postprocess input specifications into patterns that target
postprocessed outputs by ensuring each desc entity matches its corresponding
bids_desc.
Arguments
- input_dir
Directory containing postprocessed outputs.
- input_regex
One or more specifications used to match the input files. Each may be a space-separated set of BIDS entities or a regex prefixed with
"regex:".- bids_desc
One
descvalue to apply to everyinput_regex, or a vector with the same length asinput_regex. Equal-length vectors are paired by position; they are not combined as a cross-product.