List postprocessed output files for a stream based on its input spec
Source:R/setup_postprocess.R
get_postproc_output_files.RdConverts a postprocess input specification into a pattern that targets
postprocessed outputs by ensuring the desc entity matches bids_desc.